import Taro, { Component } from '@tarojs/taro'
import { View, Text, Image, Textarea } from "@tarojs/components";
import uploadLeftIcon from '../../assets/editor/left.png'
import uploadCenterIcon from '../../assets/editor/center.png'
import uploadRightIcon from '../../assets/editor/right.png'
import uploadBoldIcon from '../../assets/editor/bold.png'
import uploadItalicIcon from '../../assets/editor/italic.png'
import uploadUnderlineIcon from '../../assets/editor/line.png'
import './index.scss';
class RuiEditor extends Component {

  static defaultProps = {
    placeholder: '文字内容...',
  }


  componentDidMount() {
    const { keys, placeholder } = this.props
    // H5环境需要监听编辑器
    this.hasWeappOrWeb(() => {
      let _this = this;
      // let editor = document.getElementById('editor');
      let editor = document.getElementsByClassName('rui-div-editor')[keys]
      editor.addEventListener("focus", function () {
        if (this.innerHTML == '文字内容...') {
          this.innerHTML = '';
        }
      })
      editor.addEventListener("input", function () {
        _this.getChangeValue(_this.getWebEndHtml());
      });
      editor.addEventListener("blur", function () {
        if (this.innerHTML == '') {
          this.innerHTML = placeholder;
        }
      })
    })
  }

  shouldComponentUpdate(nextProps) {
    const { keys } = this.props
    let editor = document.getElementsByClassName('rui-div-editor')[keys]
    return nextProps.placeholder !== editor.innerHTML
  }

  componentDidUpdate() {
    const { placeholder, keys } = this.props
    let editor = document.getElementsByClassName('rui-div-editor')[keys]
    if (placeholder !== editor.innerHTML) {
      editor.innerHTML = placeholder
    }
  }

  hasWeappOrWeb(callbackweb) {
    callbackweb.call(this)
  }

  render() {
    return <View className="rui-editor-com-content">
      {/* 富文本编辑器导航 */}
      {this.getEditorNavbarHtml()}

      {/* 富文本编辑器输入框 */}
      {this.getEditorHtml()}
    </View>;
  }
  // H5改变完成获取富文本的内容输出
  getWebEndHtml() {
    const { keys } = this.props
    let editor = document.getElementsByClassName('rui-div-editor')[keys]
    // let editor = document.getElementById('editor');
    // return `<div>${editor.innerHTML}</div>`;
    return editor.innerHTML;
  }
  // 格式化等操作导航
  getEditorNavbarHtml() {
    // let { editNavs } = this.state;
    const editNavs = [
      {
        icon: uploadLeftIcon,
        event: this.hasWeappOrWeb.bind(this, this.format.bind(this, 'justifyRight'))
      },
      {
        icon: uploadCenterIcon,
        event: this.hasWeappOrWeb.bind(this, this.format.bind(this, 'justifyCenter'))
      },
      {
        icon: uploadRightIcon,
        event: this.hasWeappOrWeb.bind(this, this.format.bind(this, 'justifyLeft'))
      },
      {
        icon: uploadBoldIcon,
        event: this.format.bind(this, 'bold')
      },
      {
        icon: uploadItalicIcon,
        event: this.format.bind(this, 'italic')
      },
      {
        icon: uploadUnderlineIcon,
        event: this.format.bind(this, 'underline')
      },
    ]
    return <View className="rui-flex-sb rui-mb15">
      {
        editNavs.map((item, index) => <Image
          src={item.icon}
          key={item + index}
          onClick={item.event.bind(this)}
          className="rui-fa rui-icon35"></Image>)
      }
    </View>
  }
  // 加粗、居【左中右】等格式化
  format(name, value) {
    if (!name) return;
    this.hasWeappOrWeb.call(this, () => {
      document.execCommand(name, false, value)
    })
  }
  // 将改变的值通过onInput传出组件
  getChangeValue(value) {
    let { onInput = () => { } } = this.props;
    onInput.call(this, {
      detail: {
        html: value
      }
    });
  }
  // 获取富文本编辑器代码
  getEditorHtml() {
    let { placeholder } = this.props;
    return <View className="rui-editor">
      <div className="rui-div-editor"
        id="editor"
        suppressContentEditableWarning="true"
        contentEditable="true"
        dangerouslySetInnerHTML={{ __html: placeholder }}
      />
      {/* >{placeholder}</div> */}
    </View>
  }
}

export default RuiEditor;
