import Taro, { Component } from '@tarojs/taro'
import { View, Input, Picker, ScrollView, Button } from '@tarojs/components'
import { Loading } from '@components'
import { connect } from '@tarojs/redux'
import * as actions from '@actions/template'
import * as increase from '@actions/increase'
import TemplateList from './templatelist'
import { getWindowHeight } from '@utils/style'
import './template.scss'

@connect(state => state.home, { ...actions, ...increase })
class Template extends Component {
  config = {
    navigationBarTitleText: '模板管理'
  }

  state = {
    loading: false,
    lastItemId: 0,
    hasMore: true,
    selectorChecked: { id: 0, key: "按模板名称", value: 'title' },
    selector: [
      { id: 0, key: "按模板名称", value: 'title' },
      { id: 1, key: "按标签", value: 'tags' },],
    keyword: "",
    dataList: [],
  }

  componentDidMount() {
    this.getData()
  }


  // 列表数据
  getData = () => {
    this.setState({ loading: true })
    let payload = {
      field: this.state.selectorChecked.value,
      keyword: this.state.keyword,
    }
    this.props.getList(payload).then((data) => {
      this.setState({
        loading: false,
        dataList: data.items,
      })
    }).catch(() => {
      this.setState({ loading: false })
    })

  }

  // 删除模板
  deleteTemplate = (value) => {
    let payload = {
      id: value.id,
    }
    this.props.deleteTemplate(payload).then((data) => {
      this.setState({
        loading: false,
      })
      Taro.showToast({
        title: "操作成功",
        icon: 'none'
      })
      this.getData()
    }).catch(() => {
      this.setState({ loading: false })
    })
  }

  // 使用模板创建报告
  creatReports = (obj) => {
    const payload = {
      templateId: obj.id,
    }
    this.props.creatReport(payload).then((data) => {
      Taro.navigateTo({
        url: "/pages/reportdetail/reportdetail?id=" + data
      })
    }).catch(() => {

    })
  }

  onChange = e => {
    this.setState({
      selectorChecked: this.state.selector[e.detail.value],
    })
  }

  onInput = e => {
    this.setState({
      keyword: e.detail.value
    })
  }


  render() {
    // if (this.state.loaded) {
    //   return <Loading />
    // }
    return (
      <View className='home'>
        <View className='home_head'>
          <Picker
            mode='selector'
            range={this.state.selector}
            rangeKey="key"
            value={this.state.selectorChecked.id}
            onChange={this.onChange}>
            <View className='picker'>
              {this.state.selectorChecked.key} ▼
            </View>
          </Picker>
          <Input className='input' type='text' placeholder='请输入关键词进行查询' onInput={this.onInput} />
          <View className='button'
            onClick={() => {
              this.page = 1
              this.getData()
            }}
          >搜索</View>
        </View>
        <ScrollView
          scrollY
          className='home__wrap'
          onScrollToLower={this.getData}
          style={{ height: (getWindowHeight().substring(0, getWindowHeight().length - 2) - 55) + "px" }}
        >
          <TemplateList
            list={this.state.dataList}
            deleteTemplate={e => { this.deleteTemplate(e) }}
            creatReports={e => { this.creatReports(e) }}
          />
        </ScrollView>
      </View>
    )
  }
}

export default Template