import Taro, { Component } from '@tarojs/taro'
import { View, Text, Image } from '@tarojs/components'
import md5 from 'blueimp-md5'
import { connect } from '@tarojs/redux'
import * as actions from '@actions/user'
import { ButtonItem, InputItem } from '@components'
import './user-login.scss'
import logo from '../../assets/logo.acd490fa.png'

@connect(state => state.user, actions)
class UserLoginEmail extends Component {
  config = {
    navigationBarTitleText: '登录'
  }

  state = {
    username: '',
    password: '',
    loading: false
  }

  componentDidMount() {

  }

  handleInput = (key, value) => {
    this.setState({ [key]: value })
  }


  handleLogin = () => {
    const payload = {
      mobilePhone: this.state.username,
      password: this.state.password,
      type: 1
    }
    this.setState({ loading: true })
    this.props.dispatchLogin(payload).then(() => {
      this.setState({ loading: false })

      Taro.switchTab({
        url: '/pages/list/list',
      })

    }).catch(() => {
      this.setState({ loading: false })
    })
  }

  render() {
    const { username, password, loading } = this.state
    const isBtnDisabled = !username || !password

    // XXX 暂未实现 input 的 autoFocus 的逻辑
    return (
      <View className='user-login-email'>
        <View className='user-login-email__logo'>
          <Image src={logo} className='user-login-email__logo-img' />
        </View>
        <View className='user-login-email__wrap'>
          <InputItem
            value={username}
            placeholder='用户名'
            onInput={this.handleInput.bind(this, 'username')}
          />
          <InputItem
            password
            value={password}
            placeholder='密码'
            onInput={this.handleInput.bind(this, 'password')}
          />
        </View>
        <View className='user-login-email__btn'>
          <ButtonItem
            text='登录'
            disabled={isBtnDisabled}
            loading={loading}
            onClick={this.handleLogin}
            compStyle={{
              background: '#0079C2',
              borderRadius: Taro.pxTransform(4)
            }}
            textStyle={{
              color: isBtnDisabled ? 'rgba(255, 255, 255, 0.4)' : '#ffffff'
            }}
          />
        </View>
      </View>
    )
  }
}

export default UserLoginEmail
